# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: meshtrade/option/v1/auth.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'meshtrade/option/v1/auth.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1emeshtrade/option/v1/auth.proto\x12\x13meshtrade.option.v1\x1a google/protobuf/descriptor.proto\"D\n\x0cStandardRole\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12 \n\x0bpermissions\x18\x02 \x03(\tR\x0bpermissions\"8\n\x14PermissionStringList\x12 \n\x0bpermissions\x18\x01 \x03(\tR\x0bpermissions\",\n\x14StandardRoleNameList\x12\x14\n\x05roles\x18\x01 \x03(\tR\x05roles\"K\n\x10StandardRoleList\x12\x37\n\x05roles\x18\x01 \x03(\x0b\x32!.meshtrade.option.v1.StandardRoleR\x05roles:~\n\x14required_permissions\x12\x1e.google.protobuf.MethodOptions\x18\xd1\x86\x03 \x01(\x0b\x32).meshtrade.option.v1.PermissionStringListR\x13requiredPermissions:r\n\x0erequired_roles\x12\x1e.google.protobuf.MethodOptions\x18\xd2\x86\x03 \x01(\x0b\x32).meshtrade.option.v1.StandardRoleNameListR\rrequiredRoles:l\n\x0estandard_roles\x12\x1c.google.protobuf.FileOptions\x18\xd3\x86\x03 \x01(\x0b\x32%.meshtrade.option.v1.StandardRoleListR\rstandardRolesB0Z.github.com/meshtrade/api/go/option/v1;optionv1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'meshtrade.option.v1.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z.github.com/meshtrade/api/go/option/v1;optionv1'
  _globals['_STANDARDROLE']._serialized_start=89
  _globals['_STANDARDROLE']._serialized_end=157
  _globals['_PERMISSIONSTRINGLIST']._serialized_start=159
  _globals['_PERMISSIONSTRINGLIST']._serialized_end=215
  _globals['_STANDARDROLENAMELIST']._serialized_start=217
  _globals['_STANDARDROLENAMELIST']._serialized_end=261
  _globals['_STANDARDROLELIST']._serialized_start=263
  _globals['_STANDARDROLELIST']._serialized_end=338
# @@protoc_insertion_point(module_scope)
